@@ -939,7 +939,7 @@ class AnalyzeImage(SpatialImage):
 
         .. deprecated:: 2.4.1
             ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It will raise an error in nibabel 3.0.
+            been deprecated. It raises an error as of nibabel 3.0.
 
         Parameters
         ----------
@@ -1009,7 +1009,7 @@ class AnalyzeImage(SpatialImage):
         '''
         if file_map is None:
             file_map = self.file_map
-        data = self.get_data()
+        data = np.asanyarray(self.dataobj)
         self.update_header()
         hdr = self._header
         out_dtype = self.get_data_dtype()
