@@ -27,14 +27,12 @@ exclusively) time axis. Thus, DATASET_RANK[1] will (at least as far as I (RM)
 am aware) always be >= 1. This permits sub-brick indexing common in AFNI
 programs (e.g., example4d+orig'[0]').
 """
-from __future__ import print_function, division
 
 from copy import deepcopy
 import os
 import re
 
 import numpy as np
-from six import string_types
 
 from .arrayproxy import ArrayProxy
 from .fileslice import strided_scalar
@@ -85,8 +83,8 @@ class AFNIHeaderError(HeaderDataError):
 
 
 DATA_OFFSET = 0
-TYPE_RE = re.compile('type\s*=\s*(string|integer|float)-attribute\s*\n')
-NAME_RE = re.compile('name\s*=\s*(\w+)\s*\n')
+TYPE_RE = re.compile(r'type\s*=\s*(string|integer|float)-attribute\s*\n')
+NAME_RE = re.compile(r'name\s*=\s*(\w+)\s*\n')
 
 
 def _unpack_var(var):
@@ -204,7 +202,7 @@ def parse_AFNI_header(fobj):
     [1, 1, 1]
     """
     # edge case for being fed a filename instead of a file object
-    if isinstance(fobj, string_types):
+    if isinstance(fobj, str):
         with open(fobj, 'rt') as src:
             return parse_AFNI_header(src)
     # unpack variables in HEAD file
@@ -229,7 +227,7 @@ class AFNIArrayProxy(ArrayProxy):
 
         .. deprecated:: 2.4.1
             ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It will raise an error in nibabel 3.0.
+            been deprecated. It raises an error as of nibabel 3.0.
 
         Parameters
         ----------
@@ -252,7 +250,7 @@ class AFNIArrayProxy(ArrayProxy):
             a new file handle is created every time the image is accessed.
             If ``file_like`` refers to an open file handle, this setting has no
             effect. The default value (``None``) will result in the value of
-            ``nibabel.arrayproxy.KEEP_FILE_OPEN_DEFAULT` being used.
+            ``nibabel.arrayproxy.KEEP_FILE_OPEN_DEFAULT`` being used.
         """
         super(AFNIArrayProxy, self).__init__(file_like,
                                              header,
@@ -264,19 +262,24 @@ class AFNIArrayProxy(ArrayProxy):
     def scaling(self):
         return self._scaling
 
-    def __array__(self):
-        raw_data = self.get_unscaled()
-        # datatype may change if applying self._scaling
-        return raw_data if self.scaling is None else raw_data * self.scaling
+    def _get_scaled(self, dtype, slicer):
+        raw_data = self._get_unscaled(slicer=slicer)
+        if self.scaling is None:
+            if dtype is None:
+                return raw_data
+            final_type = np.promote_types(raw_data.dtype, dtype)
+            return raw_data.astype(final_type, copy=False)
 
-    def __getitem__(self, slicer):
-        raw_data = super(AFNIArrayProxy, self).__getitem__(slicer)
-        # apply volume specific scaling (may change datatype!)
-        if self.scaling is not None:
-            fake_data = strided_scalar(self._shape)
-            _, scaling = np.broadcast_arrays(fake_data, self.scaling)
-            raw_data = raw_data * scaling[slicer]
-        return raw_data
+        # Broadcast scaling to shape of original data
+        fake_data = strided_scalar(self._shape)
+        _, scaling = np.broadcast_arrays(fake_data, self.scaling)
+
+        final_type = np.result_type(raw_data, scaling)
+        if dtype is not None:
+            final_type = np.promote_types(final_type, dtype)
+
+        # Slice scaling to give output shape
+        return raw_data * scaling[slicer].astype(final_type)
 
 
 class AFNIHeader(SpatialHeader):
@@ -488,7 +491,7 @@ class AFNIImage(SpatialImage):
            [  0.    ,   0.    ,   3.    , -52.3511],
            [  0.    ,   0.    ,   0.    ,   1.    ]])
     >>> head = load(os.path.join(datadir, 'example4d+orig.HEAD'))
-    >>> np.array_equal(head.get_data(), brik.get_data())
+    >>> np.array_equal(head.get_fdata(), brik.get_fdata())
     True
     """
 
@@ -508,7 +511,7 @@ class AFNIImage(SpatialImage):
 
         .. deprecated:: 2.4.1
             ``keep_file_open='auto'`` is redundant with `False` and has
-            been deprecated. It will raise an error in nibabel 3.0.
+            been deprecated. It raises an error as of nibabel 3.0.
 
         Parameters
         ----------
@@ -530,7 +533,7 @@ class AFNIImage(SpatialImage):
             a new file handle is created every time the image is accessed.
             If ``file_like`` refers to an open file handle, this setting has no
             effect. The default value (``None``) will result in the value of
-            ``nibabel.arrayproxy.KEEP_FILE_OPEN_DEFAULT` being used.
+            ``nibabel.arrayproxy.KEEP_FILE_OPEN_DEFAULT`` being used.
         """
         with file_map['header'].get_prepare_fileobj('rt') as hdr_fobj:
             hdr = klass.header_class.from_fileobj(hdr_fobj)
@@ -550,6 +553,7 @@ class AFNIImage(SpatialImage):
         afni.nimh.nih.gov/pub/dist/doc/program_help/README.compression.html.
         Thus, if you have AFNI files my_image.HEAD and my_image.BRIK.gz and you
         want to load the AFNI BRIK / HEAD pair, you can specify:
+
             * The HEAD filename - e.g., my_image.HEAD
             * The BRIK filename w/o compressed extension - e.g., my_image.BRIK
             * The full BRIK filename - e.g., my_image.BRIK.gz
