@@ -689,19 +689,32 @@ class EcatImageArrayProxy(object):
     def is_proxy(self):
         return True
 
-    def __array__(self):
+    def __array__(self, dtype=None):
         ''' Read of data from file
 
         This reads ALL FRAMES into one array, can be memory expensive.
 
         If you want to read only some slices, use the slicing syntax
         (``__getitem__``) below, or ``subheader.data_from_fileobj(frame)``
+
+        Parameters
+        ----------
+        dtype : numpy dtype specifier, optional
+            A numpy dtype specifier specifying the type of the returned array.
+
+        Returns
+        -------
+        array
+            Scaled image data with type `dtype`.
         '''
+        # dtype=None is interpreted as float64
         data = np.empty(self.shape)
         frame_mapping = get_frame_order(self._subheader._mlist)
         for i in sorted(frame_mapping):
             data[:, :, :, i] = self._subheader.data_from_fileobj(
                 frame_mapping[i][0])
+        if dtype is not None:
+            data = data.astype(dtype, copy=False)
         return data
 
     def __getitem__(self, sliceobj):
@@ -788,7 +801,7 @@ class EcatImage(SpatialImage):
         >>> frame0 = img.get_frame(0)
         >>> frame0.shape == (10, 10, 3)
         True
-        >>> data4d = img.get_data()
+        >>> data4d = img.get_fdata()
         >>> data4d.shape == (10, 10, 3, 1)
         True
         """
@@ -945,7 +958,7 @@ class EcatImage(SpatialImage):
 
         # It appears to be necessary to load the data before saving even if the
         # data itself is not used.
-        self.get_data()
+        self.get_fdata()
         hdr = self.header
         mlist = self._mlist
         subheaders = self.get_subheaders()
