@@ -261,9 +261,25 @@ class MincImageArrayProxy(object):
     def is_proxy(self):
         return True
 
-    def __array__(self):
-        ''' Read of data from file '''
-        return self.minc_file.get_scaled_data()
+    def __array__(self, dtype=None):
+        """ Read data from file and apply scaling, casting to ``dtype``
+
+        If ``dtype`` is unspecified, the dtype is automatically determined.
+
+        Parameters
+        ----------
+        dtype : numpy dtype specifier, optional
+            A numpy dtype specifier specifying the type of the returned array.
+
+        Returns
+        -------
+        array
+            Scaled image data with type `dtype`.
+        """
+        arr = self.minc_file.get_scaled_data(sliceobj=())
+        if dtype is not None:
+            arr = arr.astype(dtype, copy=False)
+        return arr
 
     def __getitem__(self, sliceobj):
         """ Read slice `sliceobj` of data from file """
