@@ -16,7 +16,7 @@ Test reading with something like::
 
     import nibabel as nib
     img = nib.load('my_funny.mnc')
-    data = img.get_data()
+    data = img.get_fdata()
     print(data.mean())
     print(data.max())
     print(data.min())
@@ -28,7 +28,6 @@ and compare against command line output of::
 import numpy as np
 
 from .keywordonly import kw_only_meth
-from ._h5py_compat import h5py
 
 from .minc1 import Minc1File, MincHeader, Minc1Image, MincError
 
@@ -160,6 +159,9 @@ class Minc2Image(Minc1Image):
     @classmethod
     @kw_only_meth(1)
     def from_file_map(klass, file_map, mmap=True, keep_file_open=None):
+        # Import of h5py might take awhile for MPI-enabled builds
+        # So we are importing it here "on demand"
+        from ._h5py_compat import h5py
         holder = file_map['image']
         if holder.filename is None:
             raise MincError('MINC2 needs filename for load')
