@@ -10,15 +10,13 @@
 
 NIfTI1 format defined at http://nifti.nimh.nih.gov/nifti-1/
 '''
-from __future__ import division, print_function
 import warnings
 from io import BytesIO
-from six import string_types
 
 import numpy as np
 import numpy.linalg as npl
+from numpy.compat.py3k import asstr
 
-from .py3k import asstr
 from .filebasedimages import SerializableImage
 from .volumeutils import Recoder, make_dt_codes, endian_codes
 from .spatialimages import HeaderDataError, ImageFileError
@@ -1390,7 +1388,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         if not known_intent:
             # We can set intent via an unknown integer code, but can't via an
             # unknown string label
-            if not allow_unknown or isinstance(code, string_types):
+            if not allow_unknown or isinstance(code, str):
                 raise KeyError('Unknown intent code: ' + str(code))
         if known_intent:
             icode = intent_codes.code[code]
@@ -1777,18 +1775,18 @@ class Nifti1Pair(analyze.AnalyzeImage):
             self._affine2header()
     # Copy docstring
     __init__.__doc__ = analyze.AnalyzeImage.__init__.__doc__ + '''
-    Notes
-    -----
+        Notes
+        -----
 
-    If both a `header` and an `affine` are specified, and the `affine` does
-    not match the affine that is in the `header`, the `affine` will be used,
-    but the ``sform_code`` and ``qform_code`` fields in the header will be
-    re-initialised to their default values. This is performed on the basis
-    that, if you are changing the affine, you are likely to be changing the
-    space to which the affine is pointing.  The :meth:`set_sform` and
-    :meth:`set_qform` methods can be used to update the codes after an image
-    has been created - see those methods, and the :ref:`manual
-    <default-sform-qform-codes>` for more details.  '''
+        If both a `header` and an `affine` are specified, and the `affine` does
+        not match the affine that is in the `header`, the `affine` will be used,
+        but the ``sform_code`` and ``qform_code`` fields in the header will be
+        re-initialised to their default values. This is performed on the basis
+        that, if you are changing the affine, you are likely to be changing the
+        space to which the affine is pointing.  The :meth:`set_sform` and
+        :meth:`set_qform` methods can be used to update the codes after an image
+        has been created - see those methods, and the :ref:`manual
+        <default-sform-qform-codes>` for more details.  '''
 
     def update_header(self):
         ''' Harmonize header with image data and affine
