@@ -2,12 +2,7 @@ import copy
 import numbers
 import numpy as np
 from warnings import warn
-
-try:
-    from collections.abc import MutableMapping
-except ImportError:
-    # PY2 compatibility
-    from collections import MutableMapping
+from collections.abc import MutableMapping
 
 from nibabel.affines import apply_affine
 
@@ -25,7 +20,7 @@ def is_lazy_dict(obj):
 
 
 class SliceableDataDict(MutableMapping):
-    """ Dictionary for which key access can do slicing on the values.
+    r""" Dictionary for which key access can do slicing on the values.
 
     This container behaves like a standard dictionary but extends key access to
     allow keys for key access to be indices slicing into the contained ndarray
@@ -78,7 +73,7 @@ class SliceableDataDict(MutableMapping):
 
 
 class PerArrayDict(SliceableDataDict):
-    """ Dictionary for which key access can do slicing on the values.
+    r""" Dictionary for which key access can do slicing on the values.
 
     This container behaves like a standard dictionary but extends key access to
     allow keys for key access to be indices slicing into the contained ndarray
@@ -268,9 +263,9 @@ class Tractogram(object):
     choice as long as you provide the correct `affine_to_rasmm` matrix, at
     construction time. When applied to streamlines coordinates, that
     transformation matrix should bring the streamlines back to world space
-    (RAS+ and mm space) [1]_.
+    (RAS+ and mm space) [#]_.
 
-    Moreover, when streamlines are mapped back to voxel space [2]_, a
+    Moreover, when streamlines are mapped back to voxel space [#]_, a
     streamline point located at an integer coordinate (i,j,k) is considered
     to be at the center of the corresponding voxel. This is in contrast with
     other conventions where it might have referred to a corner.
@@ -297,8 +292,8 @@ class Tractogram(object):
 
     References
     ----------
-    [1] http://nipy.org/nibabel/coordinate_systems.html#naming-reference-spaces
-    [2] http://nipy.org/nibabel/coordinate_systems.html#voxel-coordinates-are-in-voxel-space
+    .. [#] http://nipy.org/nibabel/coordinate_systems.html#naming-reference-spaces
+    .. [#] http://nipy.org/nibabel/coordinate_systems.html#voxel-coordinates-are-in-voxel-space
     """
     def __init__(self, streamlines=None,
                  data_per_streamline=None,
@@ -437,11 +432,8 @@ class Tractogram(object):
         if np.all(affine == np.eye(4)):
             return self  # No transformation.
 
-        BUFFER_SIZE = 10000000  # About 128 Mb since pts shape is 3.
-        for start in range(0, len(self.streamlines.data), BUFFER_SIZE):
-            end = start + BUFFER_SIZE
-            pts = self.streamlines._data[start:end]
-            self.streamlines.data[start:end] = apply_affine(affine, pts)
+        for i in range(len(self.streamlines)):
+            self.streamlines[i] = apply_affine(affine, self.streamlines[i])
 
         if self.affine_to_rasmm is not None:
             # Update the affine that brings back the streamlines to RASmm.
@@ -523,9 +515,9 @@ class LazyTractogram(Tractogram):
     choice as long as you provide the correct `affine_to_rasmm` matrix, at
     construction time. When applied to streamlines coordinates, that
     transformation matrix should bring the streamlines back to world space
-    (RAS+ and mm space) [1]_.
+    (RAS+ and mm space) [#]_.
 
-    Moreover, when streamlines are mapped back to voxel space [2]_, a
+    Moreover, when streamlines are mapped back to voxel space [#]_, a
     streamline point located at an integer coordinate (i,j,k) is considered
     to be at the center of the corresponding voxel. This is in contrast with
     other conventions where it might have referred to a corner.
@@ -561,8 +553,8 @@ class LazyTractogram(Tractogram):
 
     References
     ----------
-    [1] http://nipy.org/nibabel/coordinate_systems.html#naming-reference-spaces
-    [2] http://nipy.org/nibabel/coordinate_systems.html#voxel-coordinates-are-in-voxel-space
+    .. [#] http://nipy.org/nibabel/coordinate_systems.html#naming-reference-spaces
+    .. [#] http://nipy.org/nibabel/coordinate_systems.html#voxel-coordinates-are-in-voxel-space
     """
     def __init__(self, streamlines=None,
                  data_per_streamline=None,
