@@ -14,21 +14,19 @@ What is the image API?
 * ``img.shape`` (shape of data as read with ``np.array(img.dataobj)``
 * ``img.get_fdata()`` (returns floating point data as read with
   ``np.array(img.dataobj)`` and the cast to float);
-* ``img.get_data()`` (returns data as read with ``np.array(img.dataobj)``);
-* ``img.uncache()`` (``img.get_data()`` and ``img.get_data`` are allowed to
-  cache the result of the array creation.  If they do, this call empties that
-  cache.  Implement this as a no-op if ``get_fdata()``, ``get_data`` do not
-  cache.
+* ``img.uncache()`` (``img.get_fdata()`` (recommended) and ``img.get_data()``
+  (deprecated) are allowed to cache the result of the array creation.  If they
+  do, this call empties that cache.  Implement this as a no-op if
+  ``get_fdata()``, ``get_data()`` do not cache.)
 * ``img[something]`` generates an informative TypeError
 * ``img.in_memory`` is True for an array image, and for a proxy image that is
   cached, but False otherwise.
 """
-from __future__ import division, print_function, absolute_import
 
 import warnings
 from functools import partial
 from itertools import product
-from six import string_types
+import pathlib
 
 import numpy as np
 
@@ -46,9 +44,10 @@ from .. import minc1, minc2, parrec, brikhead
 from nose import SkipTest
 from nose.tools import (assert_true, assert_false, assert_raises, assert_equal)
 
-from numpy.testing import (assert_almost_equal, assert_array_equal)
+from numpy.testing import assert_almost_equal, assert_array_equal, assert_warns, assert_allclose
 from ..testing import clear_and_catch_warnings
 from ..tmpdirs import InTemporaryDirectory
+from ..deprecator import ExpiredDeprecationError
 
 from .test_api_validators import ValidateAPI
 from .test_helpers import (bytesio_round_trip, bytesio_filemap,
@@ -94,7 +93,7 @@ class GenericImageAPI(ValidateAPI):
                 ``data_summary`` : dict with data ``min``, ``max``, ``mean``;
               * ``shape`` : shape of image;
               * ``affine`` : shape (4, 4) affine array for image;
-              * ``dtype`` : dtype of data returned from ``get_data()``;
+              * ``dtype`` : dtype of data returned from ``np.asarray(dataobj)``;
               * ``is_proxy`` : bool, True if image data is proxied;
 
         Notes
@@ -133,8 +132,7 @@ class GenericImageAPI(ValidateAPI):
         rt_img = bytesio_round_trip(img)
         assert_array_equal(img.shape, rt_img.shape)
         assert_almost_equal(img.get_fdata(), rt_img.get_fdata())
-        # get_data will be deprecated
-        assert_almost_equal(img.get_data(), rt_img.get_data())
+        assert_almost_equal(np.asanyarray(img.dataobj), np.asanyarray(rt_img.dataobj))
         # Give the image a file map
         klass = type(img)
         rt_img.file_map = bytesio_filemap(klass)
@@ -142,29 +140,39 @@ class GenericImageAPI(ValidateAPI):
         rt_img.to_file_map()
         rt_rt_img = klass.from_file_map(rt_img.file_map)
         assert_almost_equal(img.get_fdata(), rt_rt_img.get_fdata())
-        # get_data will be deprecated
-        assert_almost_equal(img.get_data(), rt_rt_img.get_data())
+        assert_almost_equal(np.asanyarray(img.dataobj), np.asanyarray(rt_img.dataobj))
         # get_ / set_ filename
         fname = 'an_image' + self.standard_extension
-        img.set_filename(fname)
-        assert_equal(img.get_filename(), fname)
-        assert_equal(img.file_map['image'].filename, fname)
+        for path in (fname, pathlib.Path(fname)):
+            img.set_filename(path)
+            assert_equal(img.get_filename(), str(path))
+            assert_equal(img.file_map['image'].filename, str(path))
         # to_ / from_ filename
         fname = 'another_image' + self.standard_extension
-        with InTemporaryDirectory():
-            img.to_filename(fname)
-            rt_img = img.__class__.from_filename(fname)
-            assert_array_equal(img.shape, rt_img.shape)
-            assert_almost_equal(img.get_fdata(), rt_img.get_fdata())
-            # get_data will be deprecated
-            assert_almost_equal(img.get_data(), rt_img.get_data())
-            del rt_img  # to allow windows to delete the directory
+        for path in (fname, pathlib.Path(fname)):
+          with InTemporaryDirectory():
+              # Validate that saving or loading a file doesn't use deprecated methods internally
+              with clear_and_catch_warnings() as w:
+                  warnings.simplefilter('error', DeprecationWarning)
+                  img.to_filename(path)
+                  rt_img = img.__class__.from_filename(path)
+              assert_array_equal(img.shape, rt_img.shape)
+              assert_almost_equal(img.get_fdata(), rt_img.get_fdata())
+              assert_almost_equal(np.asanyarray(img.dataobj), np.asanyarray(rt_img.dataobj))
+              del rt_img  # to allow windows to delete the directory
 
     def validate_no_slicing(self, imaker, params):
         img = imaker()
         assert_raises(TypeError, img.__getitem__, 'string')
         assert_raises(TypeError, img.__getitem__, slice(None))
 
+    def validate_get_data_deprecated(self, imaker, params):
+        # Check deprecated header API
+        img = imaker()
+        with assert_warns(DeprecationWarning):
+            data = img.get_data()
+        assert_array_equal(np.asanyarray(img.dataobj), data)
+
 
 class GetSetDtypeMixin(object):
     """ Adds dtype tests
@@ -307,18 +315,21 @@ class DataInterfaceMixin(GetSetDtypeMixin):
         # New data dtype, no caching, doesn't use or alter cache
         fdata_new_dt = img.get_fdata(caching='unchanged', dtype='f4')
         # We get back the original read, not the modified cache
-        assert_array_equal(fdata_new_dt, proxy_data.astype('f4'))
+        # Allow for small rounding error when the data is scaled with 32-bit
+        # factors, rather than 64-bit factors and then cast to float-32
+        # Use rtol/atol from numpy.allclose
+        assert_allclose(fdata_new_dt, proxy_data.astype('f4'), rtol=1e-05, atol=1e-08)
         assert_equal(fdata_new_dt.dtype, np.float32)
         # The original cache stays in place, for default float64
         assert_array_equal(img.get_fdata(), 42)
         # And for not-default float32, because we haven't cached
         fdata_new_dt[:] = 43
         fdata_new_dt = img.get_fdata(caching='unchanged', dtype='f4')
-        assert_array_equal(fdata_new_dt, proxy_data.astype('f4'))
+        assert_allclose(fdata_new_dt, proxy_data.astype('f4'), rtol=1e-05, atol=1e-08)
         # Until we reset with caching='fill', at which point we
         # drop the original float64 cache, and have a float32 cache
         fdata_new_dt = img.get_fdata(caching='fill', dtype='f4')
-        assert_array_equal(fdata_new_dt, proxy_data.astype('f4'))
+        assert_allclose(fdata_new_dt, proxy_data.astype('f4'), rtol=1e-05, atol=1e-08)
         # We're using the cache, for dtype='f4' reads
         fdata_new_dt[:] = 43
         assert_array_equal(img.get_fdata(dtype='f4'), 43)
@@ -412,10 +423,8 @@ class DataInterfaceMixin(GetSetDtypeMixin):
     def validate_shape_deprecated(self, imaker, params):
         # Check deprecated get_shape API
         img = imaker()
-        with clear_and_catch_warnings() as w:
-            warnings.simplefilter('always', DeprecationWarning)
-            assert_equal(img.get_shape(), params['shape'])
-            assert_equal(len(w), 1)
+        with assert_raises(ExpiredDeprecationError):
+            img.get_shape()
 
     def validate_mmap_parameter(self, imaker, params):
         img = imaker()
@@ -519,7 +528,7 @@ class SerializeMixin(object):
                     img_b = klass.from_bytes(fobj.read())
 
                 assert self._header_eq(img_a.header, img_b.header)
-                assert np.array_equal(img_a.get_data(), img_b.get_data())
+                assert np.array_equal(img_a.get_fdata(), img_b.get_fdata())
                 del img_a
                 del img_b
 
@@ -539,7 +548,7 @@ class SerializeMixin(object):
 
                 assert img_b.to_bytes() == bytes_a
                 assert self._header_eq(img_a.header, img_b.header)
-                assert np.array_equal(img_a.get_data(), img_b.get_data())
+                assert np.array_equal(img_a.get_fdata(), img_b.get_fdata())
                 del img_a
                 del img_b
 
@@ -578,7 +587,7 @@ class LoadImageAPI(GenericImageAPI,
             assert_true(isinstance(test, bool))
             if sniff is not None:
                 assert isinstance(sniff[0], bytes)
-                assert isinstance(sniff[1], string_types)
+                assert isinstance(sniff[1], str)
 
 
 class MakeImageAPI(LoadImageAPI):
